==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-dropdown-item-component-event-args.js <==
import { DropdownItemComponentEventArgs as DropdownItemComponentEventArgs_internal } from "./DropdownItemComponentEventArgs";
var IgrDropdownItemComponentEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrDropdownItemComponentEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrDropdownItemComponentEventArgs.prototype.createImplementation = function () {
        return new DropdownItemComponentEventArgs_internal();
    };
    Object.defineProperty(IgrDropdownItemComponentEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrDropdownItemComponentEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrDropdownItemComponentEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrDropdownItemComponentEventArgs.prototype, "detail", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrDropdownItemComponentEventArgs;
}());
export { IgrDropdownItemComponentEventArgs };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-dropdown-item-component-event-args.js <==
import { IgrDropdownItem } from "./igr-dropdown-item";
import { DropdownItemComponentEventArgs as DropdownItemComponentEventArgs_internal } from "./DropdownItemComponentEventArgs";
var IgrDropdownItemComponentEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrDropdownItemComponentEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrDropdownItemComponentEventArgs.prototype.createImplementation = function () {
        return new DropdownItemComponentEventArgs_internal();
    };
    Object.defineProperty(IgrDropdownItemComponentEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrDropdownItemComponentEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrDropdownItemComponentEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrDropdownItemComponentEventArgs.prototype, "detail", {
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrDropdownItem({});
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrDropdownItemComponentEventArgs;
}());
export { IgrDropdownItemComponentEventArgs };
